==> projectx-sdk-1.0.58-sources.jar: cn/com/duiba/projectx/sdk/component/share/dto/ShareQueryResult.java <==
package cn.com.duiba.projectx.sdk.component.share.dto;

import cn.com.duiba.projectx.sdk.component.sendprize.dto.SendPrizeResult;

import java.util.List;

public class ShareQueryResult {

    /**
     * 当前时间戳
     */
    private Long timestamp = System.currentTimeMillis();

    /**
     * 组件开始时间
     */
    private Long startTimestamp;

    /**
     * 组件结束时间
     */
    private Long endTimestamp;

    /**
     * 当前周期内第几次分享
     */
    private Long index;

    /**
     * 当前这一次是否发奖
     */
    private Boolean sendPrize;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 配置奖品列表
     */
    private List<SendPrizeResult> options;

    public long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(long timestamp) {
        this.timestamp = timestamp;
    }

    public Long getIndex() {
        return index;
    }

    public void setIndex(Long index) {
        this.index = index;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public List<SendPrizeResult> getOptions() {
        return options;
    }

    public void setOptions(List<SendPrizeResult> options) {
        this.options = options;
    }

    public Boolean getSendPrize() {
        return sendPrize;
    }

    public void setSendPrize(Boolean sendPrize) {
        this.sendPrize = sendPrize;
    }

    public Long getStartTimestamp() {
        return startTimestamp;
    }

    public void setStartTimestamp(Long startTimestamp) {
        this.startTimestamp = startTimestamp;
    }

    public Long getEndTimestamp() {
        return endTimestamp;
    }

    public void setEndTimestamp(Long endTimestamp) {
        this.endTimestamp = endTimestamp;
    }
}

==> projectx-sdk-1.1.63-sources.jar: cn/com/duiba/projectx/sdk/component/share/dto/ShareQueryResult.java <==
package cn.com.duiba.projectx.sdk.component.share.dto;

import cn.com.duiba.projectx.sdk.component.sendprize.dto.SendPrizeResult;

import java.util.List;

public class ShareQueryResult {

    /**
     * 当前时间戳
     */
    private Long timestamp = System.currentTimeMillis();

    /**
     * 组件开始时间
     */
    private Long startTimestamp;

    /**
     * 组件结束时间
     */
    private Long endTimestamp;

    /**
     * 当前周期内第几次分享
     */
    private Long index;

    /**
     * 当前这一次是否发奖
     */
    private Boolean sendPrize;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 配置奖品列表
     */
    private List<SendPrizeResult> options;

    /**
     * 领奖Code
     */
    private String prizePendingCode;

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public Long getStartTimestamp() {
        return startTimestamp;
    }

    public void setStartTimestamp(Long startTimestamp) {
        this.startTimestamp = startTimestamp;
    }

    public Long getEndTimestamp() {
        return endTimestamp;
    }

    public void setEndTimestamp(Long endTimestamp) {
        this.endTimestamp = endTimestamp;
    }

    public Long getIndex() {
        return index;
    }

    public void setIndex(Long index) {
        this.index = index;
    }

    public Boolean getSendPrize() {
        return sendPrize;
    }

    public void setSendPrize(Boolean sendPrize) {
        this.sendPrize = sendPrize;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public List<SendPrizeResult> getOptions() {
        return options;
    }

    public void setOptions(List<SendPrizeResult> options) {
        this.options = options;
    }

    public String getPrizePendingCode() {
        return prizePendingCode;
    }

    public void setPrizePendingCode(String prizePendingCode) {
        this.prizePendingCode = prizePendingCode;
    }
}
